@@ -1,7 +1,7 @@
 // qsamplerMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2017, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -1046,10 +1046,8 @@ bool MainForm::saveSessionFile ( const QString& sFilename )
 	int iErrors = 0;
 	QTextStream ts(&file);
 	ts << "# " << QSAMPLER_TITLE " - " << tr(QSAMPLER_SUBTITLE) << endl;
-	ts << "# " << tr("Version")
-	<< ": " CONFIG_BUILD_VERSION << endl;
-	ts << "# " << tr("Build")
-	<< ": " CONFIG_BUILD_DATE << endl;
+	ts << "# " << tr("Version") << ": " CONFIG_BUILD_VERSION << endl;
+//	ts << "# " << tr("Build") << ": " CONFIG_BUILD_DATE << endl;
 	ts << "#"  << endl;
 	ts << "# " << tr("File")
 	<< ": " << QFileInfo(sFilename).fileName() << endl;
@@ -1960,72 +1958,55 @@ void MainForm::helpAboutQt (void)
 // Show information about application program.
 void MainForm::helpAbout (void)
 {
+	QStringList list;
+#ifdef CONFIG_DEBUG
+	list << tr("Debugging option enabled.");
+#endif
+#ifndef CONFIG_LIBGIG
+	list << tr("GIG (libgig) file support disabled.");
+#endif
+#ifndef CONFIG_INSTRUMENT_NAME
+	list << tr("LSCP (liblscp) instrument_name support disabled.");
+#endif
+#ifndef CONFIG_MUTE_SOLO
+	list << tr("Sampler channel Mute/Solo support disabled.");
+#endif
+#ifndef CONFIG_AUDIO_ROUTING
+	list << tr("LSCP (liblscp) audio_routing support disabled.");
+#endif
+#ifndef CONFIG_FXSEND
+	list << tr("Sampler channel Effect Sends support disabled.");
+#endif
+#ifndef CONFIG_VOLUME
+	list << tr("Global volume support disabled.");
+#endif
+#ifndef CONFIG_MIDI_INSTRUMENT
+	list << tr("MIDI instrument mapping support disabled.");
+#endif
+#ifndef CONFIG_EDIT_INSTRUMENT
+	list << tr("Instrument editing support disabled.");
+#endif
+#ifndef CONFIG_EVENT_CHANNEL_MIDI
+	list << tr("Channel MIDI event support disabled.");
+#endif
+#ifndef CONFIG_EVENT_DEVICE_MIDI
+	list << tr("Device MIDI event support disabled.");
+#endif
+#ifndef CONFIG_MAX_VOICES
+	list << tr("Runtime max. voices / disk streams support disabled.");
+#endif
+
 	// Stuff the about box text...
 	QString sText = "<p>\n";
 	sText += "<b>" QSAMPLER_TITLE " - " + tr(QSAMPLER_SUBTITLE) + "</b><br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
-#ifdef CONFIG_DEBUG
-	sText += "<small><font color=\"red\">";
-	sText += tr("Debugging option enabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_LIBGIG
-	sText += "<small><font color=\"red\">";
-	sText += tr("GIG (libgig) file support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_INSTRUMENT_NAME
-	sText += "<small><font color=\"red\">";
-	sText += tr("LSCP (liblscp) instrument_name support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_MUTE_SOLO
-	sText += "<small><font color=\"red\">";
-	sText += tr("Sampler channel Mute/Solo support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_AUDIO_ROUTING
-	sText += "<small><font color=\"red\">";
-	sText += tr("LSCP (liblscp) audio_routing support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_FXSEND
-	sText += "<small><font color=\"red\">";
-	sText += tr("Sampler channel Effect Sends support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_VOLUME
-	sText += "<small><font color=\"red\">";
-	sText += tr("Global volume support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_MIDI_INSTRUMENT
-	sText += "<small><font color=\"red\">";
-	sText += tr("MIDI instrument mapping support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_EDIT_INSTRUMENT
-	sText += "<small><font color=\"red\">";
-	sText += tr("Instrument editing support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_EVENT_CHANNEL_MIDI
-	sText += "<small><font color=\"red\">";
-	sText += tr("Channel MIDI event support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_EVENT_DEVICE_MIDI
-	sText += "<small><font color=\"red\">";
-	sText += tr("Device MIDI event support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_MAX_VOICES
-	sText += "<small><font color=\"red\">";
-	sText += tr("Runtime max. voices / disk streams support disabled.");
-	sText += "</font></small><br />";
-#endif
+//	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
+	if (!list.isEmpty()) {
+		sText += "<small><font color=\"red\">";
+		sText += list.join("<br />\n");
+		sText += "</font></small>";
+	}
 	sText += "<br />\n";
 	sText += tr("Using") + ": ";
 	sText += ::lscp_client_package();
@@ -2820,7 +2801,7 @@ void MainForm::startServer (void)
 
 	// OK. Let's build the startup process...
 	m_pServer = new QProcess();
-	bForceServerStop = true;
+	m_bForceServerStop = true;
 
 	// Setup stdout/stderr capture...
 	m_pServer->setProcessChannelMode(QProcess::ForwardedChannels);
@@ -2864,7 +2845,7 @@ void MainForm::startServer (void)
 
 
 // Stop linuxsampler server...
-void MainForm::stopServer (bool bInteractive)
+void MainForm::stopServer ( bool bInteractive )
 {
 	// Stop client code.
 	stopClient();
@@ -2878,14 +2859,13 @@ void MainForm::stopServer (bool bInteractive)
 			"sampler session at any time by relaunching QSampler.\n\n"
 			"Do you want LinuxSampler to stop?"),
 			QMessageBox::Yes | QMessageBox::No,
-			QMessageBox::Yes) == QMessageBox::No)
-		{
-			bForceServerStop = false;
+			QMessageBox::Yes) == QMessageBox::No) {
+			m_bForceServerStop = false;
 		}
 	}
 
 	// And try to stop server.
-	if (m_pServer && bForceServerStop) {
+	if (m_pServer && m_bForceServerStop) {
 		appendMessages(tr("Server is stopping..."));
 		if (m_pServer->state() == QProcess::Running) {
 		#if defined(WIN32)
@@ -2925,7 +2905,7 @@ void MainForm::processServerExit (void)
 	if (m_pMessages)
 		m_pMessages->flushStdoutBuffer();
 
-	if (m_pServer && bForceServerStop) {
+	if (m_pServer && m_bForceServerStop) {
 		if (m_pServer->state() != QProcess::NotRunning) {
 			appendMessages(tr("Server is being forced..."));
 			// Force final server shutdown...
@@ -3002,6 +2982,7 @@ bool MainForm::startClient (void)
 		stabilizeForm();
 		return false;
 	}
+
 	// Just set receive timeout value, blindly.
 	::lscp_client_set_timeout(m_pClient, m_pOptions->iServerTimeout);
 	appendMessages(
